# ------- generated by typeit -------
from typing import Any, NamedTuple, Optional, Sequence
# from typeit import TypeConstructor


class Data(NamedTuple):
    Token: str
    TTL: int
    Firstname: str
    Lastname: str
    Company: str
    Email: str
    Language: str
    Role: int
    Privacy: int
    PrivacyDate: str
    AvatarTimestamp: str
    Legal: Sequence


class Token(NamedTuple):
    Status: int
    ErrMsg: str
    ts: str
    Data: Data


# mk_main, serialize_main =  Main